pub struct GraphemeClusterSegmenter(GraphemeClusterSegmenter);Expand description
An ICU4X grapheme-cluster-break segmenter, capable of finding grapheme cluster breakpoints in strings.
Tuple Fields
0: GraphemeClusterSegmenterImplementations
Sourceimpl GraphemeClusterSegmenter
impl GraphemeClusterSegmenter
Sourcepub fn create() -> Box<GraphemeClusterSegmenter>
pub fn create() -> Box<GraphemeClusterSegmenter>
Construct an GraphemeClusterSegmenter using compiled data.
Sourcepub fn segment_utf8<'a>(
&'a self,
input: &'a DiplomatStr,
) -> Box<GraphemeClusterBreakIteratorUtf8<'a>>
pub fn segment_utf8<'a>( &'a self, input: &'a DiplomatStr, ) -> Box<GraphemeClusterBreakIteratorUtf8<'a>>
Segments a string.
Ill-formed input is treated as if errors had been replaced with REPLACEMENT CHARACTERs according to the WHATWG Encoding Standard.
Sourcepub fn segment_utf16<'a>(
&'a self,
input: &'a DiplomatStr16,
) -> Box<GraphemeClusterBreakIteratorUtf16<'a>>
pub fn segment_utf16<'a>( &'a self, input: &'a DiplomatStr16, ) -> Box<GraphemeClusterBreakIteratorUtf16<'a>>
Segments a string.
Ill-formed input is treated as if errors had been replaced with REPLACEMENT CHARACTERs according to the WHATWG Encoding Standard.
Sourcepub fn segment_latin1<'a>(
&'a self,
input: &'a [u8],
) -> Box<GraphemeClusterBreakIteratorLatin1<'a>>
pub fn segment_latin1<'a>( &'a self, input: &'a [u8], ) -> Box<GraphemeClusterBreakIteratorLatin1<'a>>
Segments a Latin-1 string.